@@ -1,6 +1,7 @@
 use chrono::NaiveDateTime;
+use std::path::Path;
 
-#[derive(Debug, Display, Copy, Clone, Eq, PartialEq)]
+#[derive(Debug, Copy, Clone, Eq, PartialEq)]
 pub enum EventType {
     Exec,
     ExecDone,
@@ -10,8 +11,15 @@ pub enum EventType {
 
 #[derive(Debug)]
 pub enum EventData<'a> {
-    Exec { content: &'a str, args: &'a str },
-    ExecDone { code: i32, main_event_id: i64 },
+    Exec {
+        content: &'a str,
+        args: &'a str,
+        dir: Option<&'a Path>,
+    },
+    ExecDone {
+        code: i32,
+        main_event_id: i64,
+    },
     Read,
     Write,
 }
